find_fleet_config

Function find_fleet_config 

pub fn find_fleet_config() -> Result<Option<(FleetConfig, PathBuf)>>
Search for mvm.toml starting from cwd, walking up the directory tree.

Returns (config, directory_containing_mvm_toml) so flake paths can be resolved relative to the config file location.