Module shell_init

Module shell_init 

Functions

detect_kv_root
Detect the KV workspace root by walking up from cwd to find the mvm repo, then returning its parent directory.
ensure_shell_init
Ensure the shell init block is present in the host’s shell rc file. Appends it if the marker is not found. Idempotent.
ensure_shell_init_in_vm
Ensure the shell init block is present in the Lima VM’s ~/.bashrc.
generate_block
Generate the shell init block with completions and dev aliases.
print_shell_init
Print the shell init block to stdout (for eval "$(mvmctl shell-init)").