detect_kv_root

Function detect_kv_root 

pub fn detect_kv_root() -> Result<PathBuf>
Detect the KV workspace root by walking up from cwd to find the mvm repo, then returning its parent directory.

Looks for a Cargo.toml containing name = "mvmctl" to identify the repo root.