pub fn spinner(msg: &str) -> ProgressBarExpand description
Create and start a spinner with the given message.
Call .finish_with_message() or .finish_and_clear() when done.
pub fn spinner(msg: &str) -> ProgressBarCreate and start a spinner with the given message.
Call .finish_with_message() or .finish_and_clear() when done.