Module watch

Module watch 

Functions

display_trigger
Format a trigger path for display, relative to the flake directory if possible.
wait_for_changes
Wait for filesystem changes in the given flake directory.