pub fn shell_quote(arg: &str) -> String
Quote a single argument for inclusion in a shell command line.
Wraps in single quotes and escapes embedded single quotes the portable POSIX way (' → '\'').
'
'\''